@@ -1,5 +1,5 @@
 # encoding=UTF-8
-# Copyright © 2008, 2009 Jakub Wilk <ubanus@users.sf.net>
+# Copyright © 2008, 2009 Jakub Wilk <jwilk@jwilk.net>
 #
 # This package is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -120,6 +120,10 @@ class BorderShadow(Border):
             raise ValueError
         self._width = width
 
+    @property
+    def width(self):
+        return self._width
+
     def _get_sexpr(self):
         return djvu.sexpr.Expression((self.SYMBOL, self._width))
 
